==> opentelemetry-jdbc-2.21.0-alpha-sources.jar: io/opentelemetry/instrumentation/jdbc/datasource/JdbcTelemetry.java <==
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package io.opentelemetry.instrumentation.jdbc.datasource;

import io.opentelemetry.api.OpenTelemetry;
import io.opentelemetry.instrumentation.api.instrumenter.Instrumenter;
import io.opentelemetry.instrumentation.jdbc.internal.DbRequest;
import io.opentelemetry.instrumentation.jdbc.internal.dbinfo.DbInfo;
import javax.sql.DataSource;

/** Entrypoint for instrumenting a JDBC DataSources. */
public final class JdbcTelemetry {

  /** Returns a new {@link JdbcTelemetry} configured with the given {@link OpenTelemetry}. */
  public static JdbcTelemetry create(OpenTelemetry openTelemetry) {
    return builder(openTelemetry).build();
  }

  /** Returns a new {@link JdbcTelemetryBuilder} configured with the given {@link OpenTelemetry}. */
  public static JdbcTelemetryBuilder builder(OpenTelemetry openTelemetry) {
    return new JdbcTelemetryBuilder(openTelemetry);
  }

  private final Instrumenter<DataSource, DbInfo> dataSourceInstrumenter;
  private final Instrumenter<DbRequest, Void> statementInstrumenter;
  private final Instrumenter<DbRequest, Void> transactionInstrumenter;
  private final boolean captureQueryParameters;
  private final boolean sqlCommenterEnabled;

  JdbcTelemetry(
      Instrumenter<DataSource, DbInfo> dataSourceInstrumenter,
      Instrumenter<DbRequest, Void> statementInstrumenter,
      Instrumenter<DbRequest, Void> transactionInstrumenter,
      boolean captureQueryParameters,
      boolean sqlCommenterEnabled) {
    this.dataSourceInstrumenter = dataSourceInstrumenter;
    this.statementInstrumenter = statementInstrumenter;
    this.transactionInstrumenter = transactionInstrumenter;
    this.captureQueryParameters = captureQueryParameters;
    this.sqlCommenterEnabled = sqlCommenterEnabled;
  }

  public DataSource wrap(DataSource dataSource) {
    return new OpenTelemetryDataSource(
        dataSource,
        this.dataSourceInstrumenter,
        this.statementInstrumenter,
        this.transactionInstrumenter,
        this.captureQueryParameters,
        this.sqlCommenterEnabled);
  }
}

==> opentelemetry-jdbc-2.22.0-alpha-sources.jar: io/opentelemetry/instrumentation/jdbc/datasource/JdbcTelemetry.java <==
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package io.opentelemetry.instrumentation.jdbc.datasource;

import io.opentelemetry.api.OpenTelemetry;
import io.opentelemetry.instrumentation.api.incubator.semconv.db.internal.SqlCommenter;
import io.opentelemetry.instrumentation.api.instrumenter.Instrumenter;
import io.opentelemetry.instrumentation.jdbc.internal.DbRequest;
import io.opentelemetry.instrumentation.jdbc.internal.dbinfo.DbInfo;
import javax.sql.DataSource;

/** Entrypoint for instrumenting a JDBC DataSources. */
public final class JdbcTelemetry {

  /** Returns a new {@link JdbcTelemetry} configured with the given {@link OpenTelemetry}. */
  public static JdbcTelemetry create(OpenTelemetry openTelemetry) {
    return builder(openTelemetry).build();
  }

  /** Returns a new {@link JdbcTelemetryBuilder} configured with the given {@link OpenTelemetry}. */
  public static JdbcTelemetryBuilder builder(OpenTelemetry openTelemetry) {
    return new JdbcTelemetryBuilder(openTelemetry);
  }

  private final Instrumenter<DataSource, DbInfo> dataSourceInstrumenter;
  private final Instrumenter<DbRequest, Void> statementInstrumenter;
  private final Instrumenter<DbRequest, Void> transactionInstrumenter;
  private final boolean captureQueryParameters;
  private final SqlCommenter sqlCommenter;

  JdbcTelemetry(
      Instrumenter<DataSource, DbInfo> dataSourceInstrumenter,
      Instrumenter<DbRequest, Void> statementInstrumenter,
      Instrumenter<DbRequest, Void> transactionInstrumenter,
      boolean captureQueryParameters,
      SqlCommenter sqlCommenter) {
    this.dataSourceInstrumenter = dataSourceInstrumenter;
    this.statementInstrumenter = statementInstrumenter;
    this.transactionInstrumenter = transactionInstrumenter;
    this.captureQueryParameters = captureQueryParameters;
    this.sqlCommenter = sqlCommenter;
  }

  public DataSource wrap(DataSource dataSource) {
    return new OpenTelemetryDataSource(
        dataSource,
        this.dataSourceInstrumenter,
        this.statementInstrumenter,
        this.transactionInstrumenter,
        this.captureQueryParameters,
        this.sqlCommenter);
  }
}
